@@ -29,15 +29,23 @@ discovery = {
     "num_threads": getIntEnv('DISCOVERY_SERVER_NUM_THREADS', 5),
     "num_ping_threads": getIntEnv('DISCOVERY_SERVER_NUM_PING_THREADS', 5),
     "servingReportInterval": getIntEnv('DISCOVERY_SERVING_REPORT_INTERVAL', 5000),
+    "streaming": {
+        "messagesMemoryBuff": getIntEnv('STREAMING_MAX_BUFFER_MB', 1500),
+        "port": os.environ.get('STREAMING_DISCOVERY_PORT', 9022),
+        "statisticsInterval": os.environ.get('STREAMING_STATISTICS_INTERVAL', 2),
+        "stateful": getBoolEnv('STREAMING_STATEFUL', 'True')
+    }
+
 }
 algorithm = {
     "path": os.environ.get('ALGORITHM_PATH', "algorithm_unique_folder"),
-    "entryPoint": os.environ.get('ALGORITHM_ENTRY_POINT', "main.py")
+    "entryPoint": os.environ.get('ALGORITHM_ENTRY_POINT', "main.py"),
+    "redirectLogs": os.environ.get('REDIRECT_LOGS', False)
 }
 storage = {
     "clusterName": os.environ.get('CLUSTER_NAME', 'local'),
     "type": os.environ.get('DEFAULT_STORAGE', 'fs'),
-    "mode": os.environ.get('STORAGE_PROTOCOL', 'v2'),
+    "mode": os.environ.get('STORAGE_PROTOCOL', 'v3'),
     "encoding": os.environ.get('STORAGE_ENCODING', 'msgpack'),
     "maxCacheSize": getIntEnv('STORAGE_MAX_CACHE_SIZE', 400),
     "fs": {
@@ -49,6 +57,7 @@ storage = {
         "endpoint": os.environ.get('S3_ENDPOINT_URL', 'http://127.0.0.1:9000'),
         "region": os.environ.get('S3_REGION', ''),
         "bucketName": os.environ.get('S3_BUCKET_NAME', None),
+        "verify_ssl": getBoolEnv('S3_VERIFY_SSL', 'False')
     }
 }
 tracer = {
@@ -65,3 +74,6 @@ tracer = {
     },
     "service_name": os.environ.get('ALGORITHM_TYPE', 'algorithm')
 }
+logging = {
+    "level": os.environ.get('HKUBE_LOG_LEVEL', "INFO")
+}
